:mod:`art.defences.preprocessor`
================================
.. automodule:: art.defences.preprocessor

Base Class Preprocessor
-----------------------
.. autoclass:: Preprocessor
   :members:
   :special-members:

Feature Squeezing
-----------------
.. autoclass:: FeatureSqueezing
   :members:
   :special-members:

Gaussian Data Augmentation
--------------------------
.. autoclass:: GaussianAugmentation
   :members:
   :special-members:

InverseGAN
----------
.. autoclass:: InverseGAN
   :members:
   :special-members:

DefenseGAN
----------
.. autoclass:: DefenseGAN
   :members:
   :special-members:

JPEG Compression
----------------
.. autoclass:: JpegCompression
   :members:
   :special-members:

Label Smoothing
---------------
.. autoclass:: LabelSmoothing
   :members:
   :special-members:

Mp3 Compression
---------------
.. autoclass:: Mp3Compression
   :members:
   :special-members:

PixelDefend
-----------
.. autoclass:: PixelDefend
   :members:
   :special-members:

Resample
--------
.. autoclass:: Resample
   :members:
   :special-members:

Spatial Smoothing
-----------------
.. autoclass:: SpatialSmoothing
   :members:
   :special-members:

Spatial Smoothing - PyTorch
---------------------------
.. autoclass:: SpatialSmoothingPyTorch
   :members:
   :special-members:

Spatial Smoothing - TensorFlow v2
---------------------------------
.. autoclass:: SpatialSmoothingTensorFlowV2
   :members:
   :special-members:

Thermometer Encoding
--------------------
.. autoclass:: ThermometerEncoding
   :members:
   :special-members:

Total Variance Minimization
---------------------------
.. autoclass:: TotalVarMin
   :members:
   :special-members:

Video Compression
-----------------
.. autoclass:: VideoCompression
   :members:
   :special-members:
